# DeploymentOutput

Deployment outputs

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the output | [optional] 
**type** | **str** | The value type | [optional] 
**type_reference** | **str** | A reference to the specific type (ie. the unique name of the type) | [optional] 
**description** | **str** | output description | [optional] 
**mandatory** | **bool** | If this output is mandatory (ie. user is required to perform some action) | [optional] 
**route_hint** | **[str]** | a routing hint where the user is required to perform an action (eg. angular route) | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


